# MCMOD-Resize
## 用途
[MC百科](https://mcmod.cn)要求上传物品小贴图和大贴图，尺寸要求分别为32x32和128x128。  
对于部分无法自动修改尺寸的特殊情况，一个个修改材质大小并让它能上传并看起来合理会十分繁琐。  
这一项目通过一个合理的算法对物品贴图进行缩放，在符合贴图大小的同时保留原有长宽比，并尽量保持其与原图像质量相差无几。
## 安装
```bash
python -m pip install mcmod-resize
```
## 使用
```bash
mcmod_resize
```
具体用法可以执行此命令查看：
```bash
mcmod_resize -h
```
## 算法
先将图片以2的任意次幂缩放到离要求尺寸最近的大小（但一定小于等于要求尺寸），然后把其居中，周围以透明填充。